V2EX = way to explore
V2EX 是一个关于分享和探索的地方
Sign Up Now
For Existing Member  Sign In
V2EX  ›  necomancer  ›  全部回复第 21 页 / 共 32 页
回复总数  636
1 ... 17  18  19  20  21  22  23  24  25  26 ... 32  
❮ ❯
2019 年 5 月 5 日
回复了 oneTimeElastic 创建的主题 › Python › 怎么样找到一个列表中的连续数的第一个 index?
l = [1,2,3,3,3,9,9,9]
l = [1,9,9,9,3,2,9,9,9]
counts = [[1,0,l[0]]]
i = 0
for idx, item in enumerate(zip(l[:-1], l[1:])):
prev, nxt = item
if prev == nxt:
counts[i][0] += 1
else:
counts.append([1,nxt,idx+1])
i += 1

print(counts, l)
print(sorted(counts, key=lambda x:(x[0],x[1],-x[2]), reverse=True)[0])
# 按出现次数、元素本身大小和元素序号(逆序)排序
print(sorted(counts, key=lambda x:(x[0],x[1],-x[2]), reverse=True)[0])
# 按出现次数、元素本身大小和元素序号排序
666 啊,这事儿得多费劲……
2019 年 4 月 23 日
回复了 ht4266394 创建的主题 › Linux › Linux 做桌面哪个性能稳定些
blackbox
blacharch
也不错
2019 年 4 月 12 日
回复了 scalaer 创建的主题 › 问与答 › 请教下如何培养统计思维?
@mggis0or1 这也是没办法的事啊,你要求的范围太大了啊……不然……先看看统计推断相关的内容?是不是就满足要求了?
2019 年 4 月 12 日
回复了 scalaer 创建的主题 › 问与答 › 请教下如何培养统计思维?
s/JRSC/JRSS
2019 年 4 月 12 日
回复了 scalaer 创建的主题 › 问与答 › 请教下如何培养统计思维?
先向天再借个五百年,然后:

https://www.springer.com/series/692?detailsPage=titles

Springer Series in Statistics 欢迎你。
然后关注 JRSC,多读读文章。祝好运。
@TongyeYao 嗯……我感觉挺不错啊,一直在用。我是在天猫买的,只买过维氏,不过你这么一说我也试试双立人吧,不过用过这种超薄设计感觉回不去了。。。
2019 年 4 月 8 日
回复了 NerverLibis 创建的主题 › PHP › 统计下低学历码农转行程序员之前都在做什么工作?
@GM 你这敬佩度 log(N) 衰减啊……
2019 年 4 月 6 日
回复了 zhenghuiy 创建的主题 › 程序员 › 小谈「努力」
什么努不努力的……奈何智商是硬伤啊…… T_T ……唉……
2019 年 3 月 31 日
回复了 rootzeal 创建的主题 › 程序员 › 来来 show 智商的来做笔试题
嗯……根据这个做个邻接表然后 DFS ?非科班想的笨办法。P.S. 你的数据少一组 [c2, p2] 吧?
2019 年 3 月 29 日
回复了 SeaRecluse 创建的主题 › Python › Python * 运算会比 np.matmul 效率高吗?
* 不是矩阵乘法,计算量不一样。

In [1]:
...: a = random.random((1000,1000))

In [2]:
...: b = random.random((1000,1000))

In [3]: np.allclose(a@b, np.matmul(a,b))
Out[3]: True

In [4]: np.allclose(a*b, np.matmul(a,b))
Out[4]: False

In [5]: %timeit a@b
34.7 ms ± 1.91 ms per loop (mean ± std. dev. of 7 runs, 10 loops each)

In [6]: %timeit np.matmul(a,b)
34.6 ms ± 1.14 ms per loop (mean ± std. dev. of 7 runs, 10 loops each)

In [7]: np.__version__
Out[7]: '1.15.1'
或者 df = df.set_index(pd.to_datetime(df[5]))
再 df['ema'].plot()
df.set_index(pd.to_datetime(df[5])).plot()
或者 df2.index=pd.to_datetime(df[5])
检查一下 dtype,你需要转换成时间,字符串不行的。
2019 年 3 月 11 日
回复了 xiangyuecn 创建的主题 › 程序员 › 如何理性对待:代码还在,人不在了?
以非官方纸面答复形式提出抚恤金,并说他死于酗酒……校方这是第一时间甩锅,甚至不先论锅是不是自己的,有多大,先甩他一家伙再说……
有没有人用过 kite?
比如 kite + vscode
@yx1100 你要是用校园网应该能直接下啊?学校不一般都买版权的吗?..... 要不去找找 sci-hub 一类的网站吧
2019 年 3 月 8 日
回复了 shuizhongyu10 创建的主题 › Linux › 问个 shell 命令文件行提取问题
@shuizhongyu10 我没处理过那么大量的 A,频繁打开文件确实是瓶颈,无论文件是否在内存里。刚才搜到一个帖子,看到使用 wile read line 本身就是一个很低效的办法,看来 shell 的确不适合直接做这种事...

https://unix.stackexchange.com/questions/169716/why-is-using-a-shell-loop-to-process-text-considered-bad-practice

...😔
1 ... 17  18  19  20  21  22  23  24  25  26 ... 32  
❮ ❯
About   ·   Help   ·   Advertise   ·   Blog   ·   API   ·   FAQ   ·   Privacy   ·   Solana   ·   3634 Online   Highest 6679   ·     Select Language
创意工作者们的社区
World is powered by solitude
VERSION: 3.9.8.5 · 28ms · UTC 10:41 · PVG 18:41 · LAX 03:41 · JFK 06:41
♥ Do have faith in what you're doing.